@@ -24,7 +24,7 @@ import re
 import requests
 import xlrd
 import xlsxwriter
-from os.path import exists
+from os.path import exists, join
 
 
 PAT_英文数字 = re.compile('[a-zA-Z0-9]')
